Exec { timeout => hiera('DEFAULT_EXEC_TIMEOUT') }

$keystone_use_ssl = false
$keystone_service_name = hiera('CONFIG_KEYSTONE_SERVICE_NAME')
$keystone_cfg_ks_db_pw = hiera('CONFIG_KEYSTONE_DB_PW')
$keystone_cfg_mariadb_host = hiera('CONFIG_MARIADB_HOST')
$keystone_endpoint_cfg_ctrl_host = hiera('CONFIG_CONTROLLER_HOST')
$keystone_token_provider_str = downcase(hiera('CONFIG_KEYSTONE_TOKEN_FORMAT'))

class { 'keystone':
  admin_token         => hiera('CONFIG_KEYSTONE_ADMIN_TOKEN'),
  database_connection => "mysql://keystone_admin:${keystone_cfg_ks_db_pw}@${keystone_cfg_mariadb_host}/keystone",
  token_provider      => "keystone.token.providers.${keystone_token_provider_str}.Provider",
  verbose             => true,
  debug               => hiera('CONFIG_DEBUG_MODE'),
  service_name        => $keystone_service_name,
  enable_ssl          => $keystone_use_ssl,
}

if $keystone_service_name == 'httpd' {
  include packstack::apache_common

  class { 'keystone::wsgi::apache':
    ssl => $keystone_use_ssl,
  }
}

class { 'keystone::roles::admin':
  email        => 'root@localhost',
  password     => hiera('CONFIG_KEYSTONE_ADMIN_PW'),
  admin_tenant => 'admin',
}

class { 'keystone::endpoint':
  public_url   => "http://${keystone_endpoint_cfg_ctrl_host}:5000",
  internal_url => "http://${keystone_endpoint_cfg_ctrl_host}:5000",
  admin_url    => "http://${keystone_endpoint_cfg_ctrl_host}:35357",
  region       => hiera('CONFIG_KEYSTONE_REGION'),
}

# Run token flush every minute (without output so we won't spam admins)
cron { 'token-flush':
  ensure  => 'present',
  command => '/usr/bin/keystone-manage token_flush >/dev/null 2>&1',
  minute  => '*/1',
  user    => 'keystone',
  require => [User['keystone'], Group['keystone']],
} ->
service { 'crond':
  ensure => 'running',
  enable => true,
}

create_resources(packstack::firewall, hiera('FIREWALL_KEYSTONE_RULES', {}))



class { 'glance::keystone::auth':
  region           => hiera('CONFIG_KEYSTONE_REGION'),
  password         => hiera('CONFIG_GLANCE_KS_PW'),
  public_address   => hiera('CONFIG_STORAGE_HOST'),
  admin_address    => hiera('CONFIG_STORAGE_HOST'),
  internal_address => hiera('CONFIG_STORAGE_HOST'),
}


class { 'cinder::keystone::auth':
  region           => hiera('CONFIG_KEYSTONE_REGION'),
  password         => hiera('CONFIG_CINDER_KS_PW'),
  public_address   => hiera('CONFIG_STORAGE_HOST'),
  admin_address    => hiera('CONFIG_STORAGE_HOST'),
  internal_address => hiera('CONFIG_STORAGE_HOST'),
}



class { 'nova::keystone::auth':
  region           => hiera('CONFIG_KEYSTONE_REGION'),
  password         => hiera('CONFIG_NOVA_KS_PW'),
  public_address   => hiera('CONFIG_CONTROLLER_HOST'),
  admin_address    => hiera('CONFIG_CONTROLLER_HOST'),
  internal_address => hiera('CONFIG_CONTROLLER_HOST'),
  cinder           => true,
}


class { 'neutron::keystone::auth':
  region           => hiera('CONFIG_KEYSTONE_REGION'),
  password         => hiera('CONFIG_NEUTRON_KS_PW'),
  public_address   => hiera('CONFIG_CONTROLLER_HOST'),
  admin_address    => hiera('CONFIG_CONTROLLER_HOST'),
  internal_address => hiera('CONFIG_CONTROLLER_HOST'),
}

class { 'swift::keystone::auth':
  public_address => hiera('CONFIG_CONTROLLER_HOST'),
  region         => hiera('CONFIG_KEYSTONE_REGION'),
  password       => hiera('CONFIG_SWIFT_KS_PW'),
}
